@@ -1,7 +1,9 @@
 package Sah::Schema::percent;
 
-our $DATE = '2020-03-08'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-27'; # DATE
+our $DIST = 'Sah-Schemas-Float'; # DIST
+our $VERSION = '0.009'; # VERSION
 
 our $schema = ['float', {
     summary => 'A float',
@@ -11,6 +13,11 @@ This type is basically `float`, with `str_as_percent` coerce rule. So the
 percent sign is optional, but the number is always interpreted as percent, e.g.
 "1" is interpreted as 1% (0.01).
 
+In general, instead of using this schema, I recommend just using the `float`
+type (which by default includes coercion rule to convert from percent notation
+e.g. '1%' -> 0.01). Use this schema if your argument really needs to be
+expressed in percents.
+
 _
     'x.perl.coerce_rules' => [
         'From_str::as_percent',
@@ -39,22 +46,36 @@ Sah::Schema::percent - A float
 
 =head1 VERSION
 
-This document describes version 0.008 of Sah::Schema::percent (from Perl distribution Sah-Schemas-Float), released on 2020-03-08.
+This document describes version 0.009 of Sah::Schema::percent (from Perl distribution Sah-Schemas-Float), released on 2020-05-27.
 
 =head1 SYNOPSIS
 
-Using with L<Data::Sah>:
+To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
- my $vdr = gen_validator("percent*");
- say $vdr->($data) ? "valid" : "INVALID!";
+ my $validator = gen_validator("percent*");
+ say $validator->($data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create a validator to return error message, coerced value,
- # even validators in other languages like JavaScript, from the same schema.
- # See its documentation for more details.
+ # Data::Sah can also create validator that returns nice error message string
+ # and/or coerced value. Data::Sah can even create validator that targets other
+ # language, like JavaScript. All from the same schema. See its documentation
+ # for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+To validate function parameters against this schema (requires L<Params::Sah>):
 
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my @args = @_;
+     state $validator = gen_validator("percent*");
+     $validator->(\@args);
+     ...
+ }
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> to create a CLI:
+
+ # in lib/MyApp.pm
  package MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
@@ -72,6 +93,21 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      my %args = @_;
      ...
  }
+ 1;
+
+ # in myapp.pl
+ package main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
 
 Sample data:
 
@@ -89,6 +125,11 @@ This type is basically C<float>, with C<str_as_percent> coerce rule. So the
 percent sign is optional, but the number is always interpreted as percent, e.g.
 "1" is interpreted as 1% (0.01).
 
+In general, instead of using this schema, I recommend just using the C<float>
+type (which by default includes coercion rule to convert from percent notation
+e.g. '1%' -> 0.01). Use this schema if your argument really needs to be
+expressed in percents.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Float>.
