@@ -1,7 +1,7 @@
 package Sah::Schemas::Float;
 
-our $DATE = '2020-03-08'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2020-05-27'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas for various floating types
@@ -18,7 +18,7 @@ Sah::Schemas::Float - Sah schemas for various floating types
 
 =head1 VERSION
 
-This document describes version 0.008 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2020-03-08.
+This document describes version 0.009 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2020-05-27.
 
 =head1 SAH SCHEMAS
 
@@ -36,6 +36,11 @@ This type is basically C<float>, with C<str_as_percent> coerce rule. So the
 percent sign is optional, but the number is always interpreted as percent, e.g.
 "1" is interpreted as 1% (0.01).
 
+In general, instead of using this schema, I recommend just using the C<float>
+type (which by default includes coercion rule to convert from percent notation
+e.g. '1%' -> 0.01). Use this schema if your argument really needs to be
+expressed in percents.
+
 
 =item * L<posfloat|Sah::Schema::posfloat>
 
